==> webdrivermanager_cn-2.1.4-py3-none-any.whl: webdrivermanager_cn/driver/chrome.py <==
from webdrivermanager_cn.core.driver import DriverManager, DriverType
from webdrivermanager_cn.core.mirror_manager import MirrorType
from webdrivermanager_cn.core.version_manager import ChromeDriverVersionManager


class ChromeDriver(DriverManager):
    def __init__(self, version='latest', path=None, mirror_type: MirrorType = None):
        super().__init__(
            driver_name=DriverType.chrome,
            version=version,
            root_dir=path,
            mirror_type=mirror_type,
        )

    @property
    def download_url(self) -> str:
        new_version = ChromeDriverVersionManager(self.download_version)
        mirror = self.mirror.mirror_url(new_version.is_new_version)
        if self.mirror.is_huawei or (self.mirror.is_ali and not self.version_manager.is_new_version):
            url = f'{mirror}/{self.download_version}/{self.get_driver_name}'
        else:
            url = f'{mirror}/{self.download_version}/{self.get_os_info}/{self.get_driver_name}'
        self.log.debug(f'拼接下载url {self.mirror_type} - {url}')
        return url

    @property
    def version_manager(self):
        return ChromeDriverVersionManager(version=self.driver_version)

    @property
    def get_driver_name(self) -> str:
        _name = f"chromedriver-{self.get_os_info}.zip"
        return _name if self.version_manager.is_new_version else _name.replace('-', '_')

    @property
    def get_os_info(self):
        _os_type = f"{self.os_info.get_os_type}{self.os_info.get_framework}"
        if self.os_info.is_mac:
            mac_suffix = self.os_info.get_mac_framework
            if mac_suffix and mac_suffix in _os_type:
                return "mac-arm64"
            else:
                return "mac-x64"
        elif self.os_info.is_win:
            if not self.version_manager.is_new_version:
                return 'win32'
        return _os_type

==> webdrivermanager_cn-2.1.5-py3-none-any.whl: webdrivermanager_cn/driver/chrome.py <==
from webdrivermanager_cn.core.driver import DriverManager, DriverType
from webdrivermanager_cn.core.mirror_manager import MirrorType
from webdrivermanager_cn.core.version_manager import ChromeDriverVersionManager


class ChromeDriver(DriverManager):
    def __init__(self, version='latest', path=None, mirror_type: MirrorType = None):
        super().__init__(
            driver_name=DriverType.chrome,
            version=version,
            root_dir=path,
            mirror_type=mirror_type,
        )

    @property
    def download_url(self) -> str:
        new_version = self.version_manager.is_new_version
        mirror = self.mirror.mirror_url(new_version)
        if self.mirror.is_huawei or (self.mirror.is_ali and not new_version):
            url = f'{mirror}/{self.download_version}/{self.get_driver_name}'
        else:
            url = f'{mirror}/{self.download_version}/{self.get_os_info}/{self.get_driver_name}'
        self.log.debug(f'拼接下载url {self.mirror_type} - {url}')
        return url

    @property
    def version_manager(self):
        return ChromeDriverVersionManager(version=self.driver_version)

    @property
    def get_driver_name(self) -> str:
        _name = f"chromedriver-{self.get_os_info}.zip"
        return _name if self.version_manager.is_new_version else _name.replace('-', '_')

    @property
    def get_os_info(self):
        _os_type = f"{self.os_info.get_os_type}{self.os_info.get_framework}"
        if self.os_info.is_mac:
            mac_suffix = self.os_info.get_mac_framework
            if mac_suffix and mac_suffix in _os_type:
                return "mac-arm64"
            else:
                return "mac-x64"
        elif self.os_info.is_win:
            if not self.version_manager.is_new_version:
                return 'win32'
        return _os_type
